import requests


class PhoneNumberValidator:

	def __init__(self, api_key: str) -> None:
		self.api_key = api_key
		self.api_url = "https://api.numlookupapi.com/v1/validate/"
	pass

	def validate(self, phone_number: str, country_code: str = None) -> bool:
		if not phone_number:
			raise ValueError("Phone Number cannot be empty!")
		response = self._make_api_call(phone_number, country_code)
		if response.ok:
			return response.json()["valid"]
		else:
			response.raise_for_status()
	pass

	def _make_api_call(self, phone_number: str, country_code: str = None):
		params = {"apikey": self.api_key}
		if country_code:
			params["country_code"] = country_code
		response = requests.get(self.api_url + phone_number, params=params)
		return response
	pass

pass


from validator import PhoneNumberValidator

validator = PhoneNumberValidator(api_key="num_live_78XlfaLfYOT9JbY7wc3bNGY8U4DpwpzDNtJiGQ67")
is_valid1 = validator.validate("+15551234")
is_valid2= validator.validate("+12069220880")
is_valid3= validator.validate("2069220880", country_code="US")

print(is_valid1)
print(is_valid2)
print(is_valid3)